package net.knarcraft.minstrel.command;

import net.knarcraft.minstrel.music.Playlist;
import net.knarcraft.minstrel.music.Song;
import net.knarcraft.minstrel.trait.MinstrelTrait;
import org.bukkit.SoundCategory;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

/**
 * The command for adding a new song to a minstrel
 */
public class AddSongCommand implements CommandExecutor {

    private final MinstrelTrait minstrelTrait;

    /**
     * Instantiates a new add song command
     *
     * @param minstrelTrait <p>The minstrel to run this command on</p>
     */
    public AddSongCommand(MinstrelTrait minstrelTrait) {
        this.minstrelTrait = minstrelTrait;
    }

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label,
                             @NotNull String[] args) {
        if (args.length < 4) {
            return false;
        }

        String categoryString = args[1];
        String songIdString = args[2];
        String durationString = args[3];

        Playlist playlist = minstrelTrait.getPlaylist();
        //category identifier duration
        SoundCategory category = null;
        int duration;
        if (!categoryString.equalsIgnoreCase("null")) {
            try {
                category = SoundCategory.valueOf(categoryString);
            } catch (IllegalArgumentException exception) {
                sender.sendMessage("The specified category cannot be recognized");
                return false;
            }
        }
        try {
            duration = Integer.parseInt(durationString);
        } catch (NumberFormatException exception) {
            sender.sendMessage("The duration specified is not a valid number");
            return false;
        }
        if (duration < 1) {
            sender.sendMessage("The duration specified is not positive");
            return false;
        }
        if (songIdString.trim().isEmpty()) {
            sender.sendMessage("The song identifier is empty");
            return false;
        }
        Song song = new Song(category, songIdString, duration);
        playlist.addSong(song);

        sender.sendMessage("New song added");
        return true;
    }

}
