package net.knarcraft.minstrel.command;

import net.knarcraft.minstrel.music.Playlist;
import net.knarcraft.minstrel.trait.MinstrelTrait;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

/**
 * The command for removing a song from a minstrel
 */
public class RemoveSongCommand implements CommandExecutor {

    private final MinstrelTrait minstrelTrait;

    /**
     * Instantiates a new remove song command
     *
     * @param minstrelTrait <p>The minstrel to run this command on</p>
     */
    public RemoveSongCommand(@NotNull MinstrelTrait minstrelTrait) {
        this.minstrelTrait = minstrelTrait;
    }

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label,
                             @NotNull String[] args) {
        Playlist playlist = minstrelTrait.getPlaylist();
        int index;
        try {
            index = Integer.parseInt(args[1]);
        } catch (NumberFormatException exception) {
            sender.sendMessage("The given index is not an integer");
            return false;
        }
        if (index >= 0 && playlist.getSongs().size() > index) {
            //Stop any minstrels from playing the removed song
            playlist.stop();
            playlist.removeSong(index);
            sender.sendMessage("Song removed");
        } else {
            sender.sendMessage("The specified index is outside the bounds of the playlist");
            return false;
        }
        return true;
    }

}
