package net.knarcraft.minstrel.music;

import net.knarcraft.minstrel.trait.MinstrelTrait;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * A record of the time when a specific song will end
 *
 * @param player        <p>The player the song is playing for</p>
 * @param minstrelTrait <p>The minstrel playing the song</p>
 * @param endTime       <p>The time when the song will end</p>
 */
public record SongEndTime(@NotNull Player player, @NotNull MinstrelTrait minstrelTrait,
                          long endTime) implements Comparable<SongEndTime> {

    @Override
    public boolean equals(@Nullable Object other) {
        if (!(other instanceof SongEndTime songEndTime)) {
            return false;
        }

        return player.equals(songEndTime.player) && minstrelTrait.equals(songEndTime.minstrelTrait);
    }

    @Override
    public int compareTo(@NotNull SongEndTime o) {
        long difference = this.endTime - o.endTime;
        if (difference > 0) {
            return 1;
        } else if (difference < 0) {
            return -1;
        } else {
            return 0;
        }
    }

}
